@@ -84,7 +84,7 @@ def get(args):
     import processing
     domain = args.domain
     password = getPassword(args)
-    t = token(args.user, password, args.server)
+    t = token(args.username, password, args.server)
     processing.getZone(args.server, t, domain)
 
 
@@ -93,7 +93,7 @@ def create(args):
     import processing
     domain = checkInfile(args.infile)
     password = getPassword(args)
-    t = token(args.user, password, args.server)
+    t = token(args.username, password, args.server)
     processing.createRecords(args.server, t, domain,
                              getJSON(domain, args.infile, True))
 
@@ -103,7 +103,7 @@ def delete(args):
     import processing
     domain = checkInfile(args.infile)
     password = getPassword(args)
-    t = token(args.user, password, args.server)
+    t = token(args.username, password, args.server)
     processing.deleteRecords(args.server, t,
                              getJSON(domain, args.infile, False))
 
@@ -111,12 +111,20 @@ def delete(args):
 # Define sub-commands and command line options
 def parse_options():
     import argparse
+    import os
     from __init__ import __version__
 
-    parser = argparse.ArgumentParser(description='usage')
+    server, username, password = False, False, False
 
+    CONFIGFILE = os.environ['HOME'] + '/.tdclirc'
+    if os.path.isfile(CONFIGFILE):
+        server, username, password = checkConfig(CONFIGFILE)
+
+    parser = argparse.ArgumentParser(description='usage')
     parser.add_argument('-v', '--version', action='version',
                         version=__version__)
+    parser.add_argument('--config', action='store',
+                        help='config file path')
 
     subparsers = parser.add_subparsers(help='commands')
 
@@ -130,56 +138,111 @@ def parse_options():
     # Retrieve records
     parser_get = subparsers.add_parser(
         'get', help='retrieve records of specific zone')
+    if server and username and password:
+        parser_get.set_defaults(server=server, username=username,
+                                password=password)
+    elif server and username:
+        parser_get.set_defaults(server=server, username=username)
+
     parser_get.add_argument('--domain', action='store', required=True,
                             help='specify domain FQDN')
-    parser_get.add_argument(
-        '-s', dest='server', required=True,
-        help='specify TonicDNS Server hostname or IP address')
-    parser_get.add_argument('-u', dest='user', required=True,
-                           help='TonicDNS username')
-    group_get = parser_get.add_mutually_exclusive_group(required=True)
-    group_get.add_argument('-p', dest='password',
-                           help='TonicDNS password')
-    group_get.add_argument('-P', action='store_true',
-                            help='TonicDNS password prompt')
+    if not server:
+        parser_get.add_argument(
+            '-s', dest='server', required=True,
+            help='specify TonicDNS Server hostname or IP address')
+    if not username:
+        parser_get.add_argument('-u', dest='username', required=True,
+                                help='TonicDNS username')
+    if not password:
+        group_get = parser_get.add_mutually_exclusive_group(required=True)
+        group_get.add_argument('-p', dest='password',
+                               help='TonicDNS password')
+        group_get.add_argument('-P', action='store_true',
+                               help='TonicDNS password prompt')
     parser_get.set_defaults(func=get)
 
     # Create records
     parser_create = subparsers.add_parser(
         'create', help='create records of specific zone')
+
+    if server and username and password:
+        parser_create.set_defaults(server=server, username=username,
+                                password=password)
+    elif server and username:
+        parser_create.set_defaults(server=server, username=username)
+
     parser_create.add_argument('infile', action='store',
                                  help='pre-converted text file')
-    parser_create.add_argument('-s', dest='server', required=True,
-                               help='specify TonicDNS hostname or IP address')
-    parser_create.add_argument('-u', dest='user', required=True,
-                               help='TonicDNS username')
-    group_create = parser_create.add_mutually_exclusive_group(required=True)
-    group_create.add_argument('-p', dest='password',
+    if not server:
+        parser_create.add_argument('-s', dest='server', required=True,
+                                   help='specify TonicDNS hostname|IP address')
+    if not username:
+        parser_create.add_argument('-u', dest='username', required=True,
+                                   help='TonicDNS username')
+    if not password:
+        group_create = \
+            parser_create.add_mutually_exclusive_group(required=True)
+        group_create.add_argument('-p', dest='password',
                                help='TonicDNS password')
-    group_create.add_argument('-P', action='store_true',
+        group_create.add_argument('-P', action='store_true',
                                help='TonicDNS password prompt')
     parser_create.set_defaults(func=create)
 
     # Delete records
     parser_delete = subparsers.add_parser(
         'delete', help='delete records of specific zone')
+
+    if server and username and password:
+        parser_delete.set_defaults(server=server, username=username,
+                                password=password)
+    elif server and username:
+        parser_delete.set_defaults(server=server, username=username)
+
     parser_delete.add_argument('infile', action='store',
                                  help='pre-converted text file')
-    parser_delete.add_argument('-s', dest='server', required=True,
-                               help='specify TonicDNS hostname or IP address')
-    parser_delete.add_argument('-u', dest='user', required=True,
-                               help='TonicDNS username')
-    group_delete = parser_delete.add_mutually_exclusive_group(required=True)
-    group_delete.add_argument('-p', dest='password',
-                               help='TonicDNS password')
-    group_delete.add_argument('-P', action='store_true',
-                               help='TonicDNS password prompt')
+    if not server:
+        parser_delete.add_argument('-s', dest='server', required=True,
+                                   help='specify TonicDNS hostname|IP address')
+    if not username:
+        parser_delete.add_argument('-u', dest='username', required=True,
+                                   help='TonicDNS username')
+    if not password:
+        group_delete = \
+            parser_delete.add_mutually_exclusive_group(required=True)
+        group_delete.add_argument('-p', dest='password',
+                                  help='TonicDNS password')
+        group_delete.add_argument('-P', action='store_true',
+                                  help='TonicDNS password prompt')
     parser_delete.set_defaults(func=delete)
 
     args = parser.parse_args()
     return args
 
 
+def checkConfig(filename):
+    import os.path
+    import sys
+    if sys.version_info > (2, 6) and sys.version_info < (2, 8):
+        import ConfigParser as configparser
+    elif sys.version_info > (3, 0):
+        import configparser as configparser
+    conf = configparser.SafeConfigParser(allow_no_value=False)
+    conf.read(filename)
+    try:
+        server = conf.get('global', 'server')
+    except conigparser.NoOptionError:
+        server = False
+    try:
+        username = conf.get('auth', 'username')
+    except configparser.NoOptionError:
+        username = False
+    try:
+        password = conf.get('auth', 'password')
+    except configparser.NoOptionError:
+        password = False
+    return server, username, password
+
+
 def main():
     import sys
 
